@@ -1,3 +1,4 @@
+use config_file::ConfigFileType;
 use eyre::{Context, Result, bail, eyre};
 use indexmap::{IndexMap, IndexSet};
 use itertools::Itertools;
@@ -14,7 +15,6 @@ use std::sync::{Arc, Mutex, OnceLock, RwLock};
 use std::time::Duration;
 use walkdir::WalkDir;
 
-use crate::backend::ABackend;
 use crate::cli::version;
 use crate::config::config_file::idiomatic_version::IdiomaticVersionFile;
 use crate::config::config_file::mise_toml::{MiseToml, Tasks};
@@ -29,6 +29,7 @@ use crate::toolset::{
 };
 use crate::ui::style;
 use crate::{backend, dirs, env, file, lockfile, registry, runtime_symlinks, shims, timeout};
+use crate::{backend::ABackend, cli::version::VERSION};
 
 pub mod config_file;
 pub mod env_directive;
@@ -107,6 +108,7 @@ impl Config {
         trace!("config_paths: {config_paths:?}");
         let config_files = load_all_config_files(&config_paths, &idiomatic_files)?;
         time!("load config_files");
+        warn_about_idiomatic_version_files(&config_files);
 
         let mut tera_ctx = BASE_CONTEXT.clone();
         let vars_results = load_vars(tera_ctx.clone(), &config_files)?;
@@ -756,12 +758,24 @@ fn load_idiomatic_files() -> BTreeMap<String, Vec<String>> {
     if !SETTINGS.idiomatic_version_file {
         return BTreeMap::new();
     }
+    if !SETTINGS.idiomatic_version_file_disable_tools.is_empty() {
+        deprecated!(
+            "idiomatic_version_file_disable_tools",
+            "is deprecated, use idiomatic_version_file_enable_tools instead"
+        );
+    }
     let idiomatic = backend::list()
         .into_par_iter()
         .filter(|tool| {
-            !SETTINGS
-                .idiomatic_version_file_disable_tools
-                .contains(tool.id())
+            if let Some(enable_tools) = &SETTINGS.idiomatic_version_file_enable_tools {
+                enable_tools.contains(tool.id())
+            } else if !SETTINGS.idiomatic_version_file_disable_tools.is_empty() {
+                !SETTINGS
+                    .idiomatic_version_file_disable_tools
+                    .contains(tool.id())
+            } else {
+                true
+            }
         })
         .filter_map(|tool| match tool.idiomatic_filenames() {
             Ok(filenames) => Some(
@@ -1219,6 +1233,37 @@ pub fn rebuild_shims_and_runtime_symlinks(new_versions: &[ToolVersion]) -> Resul
     Ok(())
 }
 
+fn warn_about_idiomatic_version_files(config_files: &ConfigMap) {
+    if SETTINGS
+        .idiomatic_version_file_enable_tools
+        .as_ref()
+        .is_some()
+    {
+        return;
+    }
+    debug_assert!(
+        !VERSION.starts_with("2026"),
+        "default idiomatic version files to disabled"
+    );
+    if let Some((p, cf)) = config_files
+        .iter()
+        .find(|(_, cf)| cf.config_type() == ConfigFileType::IdiomaticVersion)
+    {
+        let tool = cf
+            .to_toolset()
+            .ok()
+            .and_then(|ts| ts.versions.keys().map(|ba| ba.to_string()).next())
+            .unwrap_or("<TOOL>".to_string());
+        deprecated!(
+            "idiomatic_version_file_enable_tools",
+            "idiomatic version files like {} are currently enabled by default however this will change in mise 2026.1.1 to instead default to disabled.\nYou can remove this warning by explicitly enabling idiomatic version files for {} with `mise settings add idiomatic_version_file_enable_tools {}`.\nSee https://github.com/jdx/mise/discussions/4345 for more information.",
+            display_path(p),
+            tool,
+            tool
+        );
+    }
+}
+
 fn reset() {
     if let Err(err) = timeout::run_with_timeout(
         || {
